%% Script for displaying efficiency curves
% on the compresssor characteristic
% Author Thomas F. vervg

% clear all
% clc

dh1=0.095;
ds1=0.210;

d1=(dh1^2+ds1^2)^0.5;
r1=3*d1/2;
d2=0.557;
r2=4*d2/2;

rho1=1.2;
A1=0.00956;
beta1b=40*pi/180;
beta2b=90*pi/180;
nblades=22;
sigma=1-2/(nblades);
ws=10;% ????
kf=5; %?????
cp=2064;
kappa=1.3;
T01=293;
alpha=50;

%% ========================
% Speed and mass flow vectors

speed = 14000:500:19000;
w = (0.1:0.1:30);
w2 = 0:0.01:20;

%========================
v = length(speed);
n = length(w);
f = length(w2);

PSII = zeros(n,1);
my1 = zeros(n,1);
Psi=zeros(n,v);
w1=zeros(n,v);

%% ========================
% Building the speedlines

for k=1:v
    omega = speed(k)/60;
    
    for i = 1:n
    
    my1(i) = sigma*(1-cot(beta2b)/(rho1*A1*r1)*w(i)/omega);

    PSII(i) = (1+(my1(i)*r2^2*omega^2 - ((r1^2)/2)*(omega - alpha * w(i))^2 ...
              - kf*w(i)^2)/(cp*T01))^(kappa/(kappa - 1));

    end
    
    Psi(:,k)=PSII;
    w1(:,k)=w;

end

%% ========================
% Making the vectors for displaying efficiency

for t=1:f

y1(t) = 0.175*w2(t) + sqrt(0.05-(w2(t)-10)^2);
y2(t) = 0.175*w2(t) - sqrt(0.05-(w2(t)-10)^2);

y3(t) = 0.175*w2(t) + sqrt(0.2-(w2(t)-10)^2);
y4(t) = 0.175*w2(t) - sqrt(0.2-(w2(t)-10)^2);

y5(t) = 0.175*w2(t) + sqrt(0.8-(w2(t)-10)^2);
y6(t) = 0.175*w2(t) - sqrt(0.8-(w2(t)-10)^2);

y7(t) = 0.175*w2(t) + sqrt(2-(w2(t)-10)^2);
y8(t) = 0.175*w2(t) - sqrt(2-(w2(t)-10)^2);

%----------------------------------

y11(t) = 0.13*w2(t) + sqrt(0.05-(w2(t)-13)^2);
y21(t) = 0.13*w2(t) - sqrt(0.05-(w2(t)-13)^2);

y31(t) = 0.13*w2(t) + sqrt(0.2-(w2(t)-13)^2);
y41(t) = 0.13*w2(t) - sqrt(0.2-(w2(t)-13)^2);

y51(t) = 0.13*w2(t) + sqrt(0.8-(w2(t)-13)^2);
y61(t) = 0.13*w2(t) - sqrt(0.8-(w2(t)-13)^2);

y71(t) = 0.13*w2(t) + sqrt(2-(w2(t)-13)^2);
y81(t) = 0.13*w2(t) - sqrt(2-(w2(t)-13)^2);

end

figure(1)
plot(w,Psi(:,:));
hold on
plot(w2,y1,'k',w2,y2,'k',w2,y3,'k',w2,y4,'k');
hold on
plot(w2,y5,'k',w2,y6,'k',w2,y7,'k',w2,y8,'k');
axis([5 20 1 2.5])
title('Efficiency Plot Compressor one');
xlabel('w [m^3/s]');
ylabel('\Psi_c');


figure(2)
plot(w,Psi(:,:));
hold on
plot(w2,y11,'k',w2,y21,'k',w2,y31,'k',w2,y41,'k');
hold on
plot(w2,y51,'k',w2,y61,'k',w2,y71,'k',w2,y81,'k');
axis([5 20 1 2.5])
title('Efficiency Plot Compressor two');
xlabel('w [m^3/s]');
ylabel('\Psi_c');




